==> nextcloud-27.1.11.tgz: nextcloud/apps/federatedfilesharing/l10n/ko.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "잘못된 연합 클라우드 ID",
    "Server to server sharing is not enabled on this server" : "이 서버에서 서버간 공유를 사용할 수 없음",
    "Couldn't establish a federated share." : "연합 공유를 설정할 수 없습니다.",
    "Couldn't establish a federated share, maybe the password was wrong." : "연합 공유를 설정할 수 없습니다. 암호가 잘못되었을 수도 있습니다.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "연합 공유 요청을 보냈으며 초대장을 받을 것입니다. 알림을 확인하십시오.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "연합 공유를 설정할 수 없습니다. 연합하려고 하는 서버가 너무 오래되었습니다(Nextcloud 9 이하).",
    "It is not allowed to send federated group shares from this server." : "이 서버에서 연합 공유를 보낼 수 없습니다.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "%1$s을(를) 공유할 수 없습니다. 이 항목을 이미 %2$s 계정과 공유하고 있습니다",
    "Not allowed to create a federated share to the same account" : "같은 계정과 연합 공유를 만들 수 없음",
    "Federated shares require read permissions" : "연합 공유는 읽기 권한이 필요합니다",
    "File is already shared with %s" : "파일이 %s와(과) 이미 공유됨",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "%1$s 공유 실패. %2$s을(를) 찾을 수 없습니다. 서버에 접근할 수 없거나 자가 서명된 인증서를 사용하고 있을 수도 있습니다.",
    "Could not find share" : "공유를 찾을 수 없음",
    "Federated sharing" : "연합 공유",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "{user}({behalf} 대신) 님으로부터 {share}을(를) 원격 공유로 받음",
    "You received {share} as a remote share from {user}" : "{user} 님으로부터 {share}을(를) 원격 공유로 받음",
    "Accept" : "수락",
    "Decline" : "거절",
    "Federated Cloud Sharing" : "클라우드 연합 공유",
    "Sharing" : "공유",
    "Federated file sharing" : "연합 파일 공유",
    "Provide federated file sharing across servers" : "서버간 연합 파일 공유 제공",
    "Unable to update federated files sharing config" : "연합 파일 공유 설정을 갱신할 수 없음",
    "Federated Cloud" : "연합 클라우드",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloud 서버나 다른 Open Cloud Mesh(OCM) 호환 서버 및 서비스 사용자와 공유할 수 있습니다! 공유 대화 상자에 연합 클라우드 ID를 입력하십시오. person@cloud.example.com 형식입니다",
    "Your Federated Cloud ID:" : "내 연합 클라우드 ID:",
    "Share it so your friends can share files with you:" : "친구들과 파일을 공유할 수 있도록 공유하십시오:",
    "Facebook" : "Facebook",
    "Twitter" : "Twitter",
    "Add to your website" : "내 웹 사이트에 추가",
    "Share with me via Nextcloud" : "Nextcloud로 나와 공유하기",
    "HTML Code:" : "HTML 코드:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "내 #Nextcloud 연합 클라우드 ID를 통해서 공유됨, 더 알아보기: {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "내 #Nextcloud 연합 클라우드 ID를 통해서 공유됨",
    "Cloud ID copied to the clipboard" : "클라우드 ID가 클립보드에 복사됨",
    "Copy to clipboard" : "클립보드로 복사",
    "Clipboard is not available" : "클립보드를 사용할 수 없습니다.",
    "Copied!" : "복사 성공!",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote}의 원격 공유 {name}을(를) 추가하시겠습니까?",
    "Remote share" : "원격 공유",
    "Remote share password" : "원격 공유 암호",
    "Cancel" : "취소",
    "Add remote share" : "원격 공유 추가",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "%1$s을(를) 공유할 수 없습니다. 이 항목을 이미 %2$s 님과 공유하고 있습니다",
    "Not allowed to create a federated share with the same user" : "같은 사용자와 연합 공유를 만들 수 없음",
    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "서버 간 공유 방법을 설정하십시오. 이 설정은 이 서버에서 연합 공유를 사용하고 있는 사용자 간 공유에도 적용됩니다.",
    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "이 서버에서 다른 서버로 공유하도록 허용 (이 옵션은 공개 공유에 대해 WebDAV 접근을 허용합니다)",
    "Allow users on this server to receive shares from other servers" : "이 서버의 사용자가 다른 서버에서 공유한 파일을 받을 수 있도록 허용",
    "Allow users on this server to send shares to groups on other servers" : "이 서버의 사용자가 다른 서버의 그룹으로 공유를 보낼 수 있도록 허용",
    "Allow users on this server to receive group shares from other servers" : "이 서버의 사용자가 다른 서버의 그룹에서 보낸 공유를 받을 수 있도록 허용",
    "Search global and public address book for users" : "전역 및 공개 주소록에서 사용자 검색",
    "Allow users to publish their data to a global and public address book" : "사용자가 데이터를 전역 및 공개 주소록에 업로드할 수 있도록 허용"
},
"nplurals=1; plural=0;");

==> nextcloud-29.0.12.tgz: nextcloud/apps/federatedfilesharing/l10n/ko.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "잘못된 연합 클라우드 ID",
    "Server to server sharing is not enabled on this server" : "이 서버에서 서버간 공유를 사용할 수 없음",
    "Couldn't establish a federated share." : "연합 공유를 설정할 수 없습니다.",
    "Couldn't establish a federated share, maybe the password was wrong." : "연합 공유를 설정할 수 없습니다. 암호가 잘못되었을 수도 있습니다.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "연합 공유 요청을 보냈으며 초대장을 받을 것입니다. 알림을 확인하십시오.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "연합 공유를 설정할 수 없습니다. 연합하려고 하는 서버가 너무 오래되었습니다(Nextcloud 9 이하).",
    "It is not allowed to send federated group shares from this server." : "이 서버에서 연합 공유를 보낼 수 없습니다.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "%1$s을(를) 공유할 수 없습니다. 이 항목을 이미 %2$s 계정과 공유하고 있습니다",
    "Not allowed to create a federated share to the same account" : "같은 계정과 연합 공유를 만들 수 없음",
    "Federated shares require read permissions" : "연합 공유는 읽기 권한이 필요합니다",
    "File is already shared with %s" : "파일이 %s와(과) 이미 공유됨",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "%1$s 공유 실패. %2$s을(를) 찾을 수 없습니다. 서버에 접근할 수 없거나 자가 서명된 인증서를 사용하고 있을 수도 있습니다.",
    "Could not find share" : "공유를 찾을 수 없음",
    "Federated sharing" : "연합 공유",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "{user}({behalf} 대신) 님으로부터 {share}을(를) 원격 공유로 받음",
    "You received {share} as a remote share from {user}" : "{user} 님으로부터 {share}을(를) 원격 공유로 받음",
    "Accept" : "수락",
    "Decline" : "거절",
    "Federated Cloud Sharing" : "클라우드 연합 공유",
    "Sharing" : "공유",
    "Federated file sharing" : "연합 파일 공유",
    "Provide federated file sharing across servers" : "서버간 연합 파일 공유 제공",
    "Unable to update federated files sharing config" : "연합 파일 공유 설정을 갱신할 수 없음",
    "Federated Cloud" : "연합 클라우드",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloud 서버나 다른 Open Cloud Mesh(OCM) 호환 서버 및 서비스 사용자와 공유할 수 있습니다! 공유 대화 상자에 연합 클라우드 ID를 입력하십시오. person@cloud.example.com 형식입니다",
    "Share it so your friends can share files with you:" : "친구들과 파일을 공유할 수 있도록 공유하십시오:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (구 Twitter)",
    "Add to your website" : "내 웹 사이트에 추가",
    "Share with me via Nextcloud" : "Nextcloud로 나와 공유하기",
    "HTML Code:" : "HTML 코드:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "내 #Nextcloud 연합 클라우드 ID를 통해서 공유됨, 더 알아보기: {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "내 #Nextcloud 연합 클라우드 ID를 통해서 공유됨",
    "Cloud ID copied to the clipboard" : "클라우드 ID가 클립보드에 복사됨",
    "Copy to clipboard" : "클립보드로 복사",
    "Copied!" : "복사 성공!",
    "Cancel" : "취소",
    "Add remote share" : "원격 공유 추가",
    "Remote share" : "원격 공유",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote}의 원격 공유 {name}을(를) 추가하시겠습니까?",
    "Remote share password" : "원격 공유 암호",
    "Your Federated Cloud ID:" : "내 연합 클라우드 ID:",
    "Twitter" : "Twitter",
    "Clipboard is not available" : "클립보드를 사용할 수 없습니다."
},
"nplurals=1; plural=0;");
